pub enum ComponentSelector {
All,
Paths(Vec<String>),
}Expand description
A selector for components in a query.
This can either be a list of component paths or an “all” selector that
indicates that all components should be selected.
The “all” selector is useful when you want to retrieve all components
present on an entity without specifying each one individually.
The paths in the Paths variant must be the [full type paths]: e.g.
bevy_transform::components::transform::Transform, not just
Transform.
Variants
All
An “all” selector that indicates all components should be selected.
Paths(Vec<String>)
A list of component paths to select as optional components.