pub enum BrpBatch {
Batch(Vec<Value>),
Single(Value),
}Expand description
The requests may occur on their own or in batches. Actual parsing is deferred for the sake of proper error reporting.
Variants
Batch(Vec<Value>)
Multiple requests with deferred parsing.
Single(Value)
A single request with deferred parsing.