pub enum RemoteMethodHandler {
Instant(Box<dyn System<In = In<Option<Value>>, Out = BrpResult>>),
Watching(Box<dyn System<In = In<Option<Value>>, Out = BrpResult<Option<Value>>>>),
}Expand description
A type to hold the allowed types of systems to be used as method handlers.
Variants
Instant(Box<dyn System<In = In<Option<Value>>, Out = BrpResult>>)
A handler that only runs once and returns one response.
Watching(Box<dyn System<In = In<Option<Value>>, Out = BrpResult<Option<Value>>>>)
A handler that watches for changes and response when a change is detected.