pub struct RemoteHttpPlugin { /* private fields */ }Expand description
Add this plugin to your App to allow remote connections over HTTP to inspect and modify entities.
It requires the RemotePlugin.
This BRP transport cannot be used when targeting WASM.
The defaults are:
DEFAULT_ADDR: 127.0.0.1.DEFAULT_PORT: 15702.
Implementations
Sourceimpl RemoteHttpPlugin
impl RemoteHttpPlugin
Sourcepub fn with_address(self, address: impl Into<IpAddr>) -> Self
pub fn with_address(self, address: impl Into<IpAddr>) -> Self
Set the IP address that the server will use.
Sourcepub fn with_headers(self, headers: Headers) -> Self
pub fn with_headers(self, headers: Headers) -> Self
Set the extra headers that the response will include.
////// /// # Example
ⓘ
// Create CORS headers
let cors_headers = Headers::new()
.insert("Access-Control-Allow-Origin", "*")
.insert("Access-Control-Allow-Headers", "Content-Type");
// Create the Bevy app and add the RemoteHttpPlugin with CORS headers
fn main() {
App::new()
.add_plugins(DefaultPlugins)
.add_plugins(RemotePlugin::default())
.add_plugins(RemoteHttpPlugin::default()
.with_headers(cors_headers))
.run();
}Sourcepub fn with_header(
self,
name: impl TryInto<HeaderName>,
value: impl TryInto<HeaderValue>,
) -> Self
pub fn with_header( self, name: impl TryInto<HeaderName>, value: impl TryInto<HeaderValue>, ) -> Self
Add a single header to the response headers.